﻿© Fluke. All Rights Reserved.                               MET/CAL Procedure
=============================================================================
INSTRUMENT:            Sub AT DSO/DSA9xxx4A (1 yr) Measure BW Gain VISA /LO
DATE:                  2011-02-18 09:15:40
AUTHOR:                Fluke
REVISION:              $Revision: 2619 $
ADJUSTMENT THRESHOLD:  70%
NUMBER OF TESTS:       2
NUMBER OF LINES:       131
CONFIGURATION:         Agilent E4418B
CONFIGURATION:         Agilent E4412A on channel 1
CONFIGURATION:         Agilent E8257D
STANDARD:              Agilent 11667A
=============================================================================
#
#  Procedure Author:
#        DFM, CAD
#
#  Model(s) Covered:
#        Agilent 90000 Series Infiniium Oscilloscopes:
#          DSO/DSA90254A, DSO/DSA90404A, DSO/DSA90604A,
#          DSO/DSA90804A, DSO/DSA91204A, DSO/DSA91304A
#
#  Compatibility:
#        MET/CAL 7.3 or later
#
#  Subprocedures:
#        Sub Apply /LO
#        Sub Output Off /LO
#
#  Required Files:
#        None
#
#  Additional Equipment Required:
#        Adapter, 3.5 mm (f) SMA to Precision BNC,
#          Agilent Part No. 54855-67604 (No Substitute)
#        Adapter, 3.5 mm (m) to Type N (m), 1 ea.
#        Coaxial cable, 3.5 mm (f) to Type N (m), DC to >= 18 GHz, 1 ea.
#        Power Splitter, 2 resistor, DC to >= 18 GHz,
#          Agilent 11667A or equivalent
#
#  Global Variable Use:
#      @Range   - UUT time/div (i.e. "5 mV/div")
#      @LO_Ampl - Flexible Local Oscillator (generator) amplitude setting
#
#  Example usage:
#      1.001  MATH        @Range = "5 mV/div"; @LO_Ampl = "-24dBm"
#      1.002  CALL        Sub AT DSO/DSA9xxx4A (1 yr) Measure BW Gain VISA /LO
#
#  The copyright in this procedure is owned by Fluke Corporation.
#
 STEP    FSC    RANGE NOMINAL        TOLERANCE     MOD1        MOD2  3  4 CON

# Force procedure header to list the required standards.
  1.001  IF           0
  1.002  STD          Agilent 11667A
  1.003  IEEE         [@LO]
  1.004  ENDIF

# Measure and calculate the 50 MHz gain (reference).
  1.005  HEAD         -2 Channel [V @Chan]: [V @Range] @ 50 MHz
  1.006  TARGET
  1.007  VISA         TIMEBASE:SCALE 16E-9

# Set Signal Generator output for approximately 4 divisions;
# @LO_Ampl is defined by calling procedure.
  1.008  MATH         @LO_Freq = "50MHz"
  1.009  CALL         Sub Apply /LO
  1.010  WAIT         [D2000]

# Retreive and store UUT Vrms reading (Vout@50 MHz).
  1.011  VISA         MEAS:VRMS? DISP,AC,CHAN[V @Chan][I]
  1.012  MATH         Vout@50MHz = MEM

# Retreive power meter reading, convert to Vrms, and store (Vin@50 MHz).
  1.013  M4418  F64   E4412A
  1.014  4418         0.000001W                    50MH              RF N  CH1
  1.015  MATH         Vin@50MHz = SQRT(MEM * 50)

# Compute and store 50 MHz gain for subsequent use (Gain@50MHz).
  1.016  MATH         Gain@50MHz = Vout@50MHz / Vin@50MHz


# ------------------------------------------------
  1.017  TARGET       -p
  1.018  VISA         TIMEBASE:SCALE 100E-12

# 91204A and 91304A are tested at 11.8 GHz on the 5 mV/div range.
  1.019  IF           (@MaxFreq >= 12) && ZCMPI(@Range, "5 mV/div")
  1.020  MATH         Freq = 11.8
  1.021  ELSE
  1.022  MATH         Freq = @MaxFreq
  1.023  ENDIF

  1.024  HEAD         -2 Channel [V @Chan]: [V @Range] @ [V Freq] GHz
  1.025  TARGET       -p

# Apply signal at Maximum Frequency (amplitude does not change).
  1.026  MATH         @LO_Freq = Freq & "GHz"
  1.027  CALL         Sub Apply /LO
  1.028  WAIT         [D2000]

# Copy measurement frequency (Freq) to MEM for use in 4418 FSC.
# Retreive power meter reading, convert to Vrms, and store (Vin@MaxFreq).
  1.029  MATH         MEM = Freq
  1.030  4418         0.000001W                    GH                RF N  CH1
  1.031  MATH         Vin@MaxFreq = SQRT(MEM * 50)

# Retreive UUT Vrms reading (Vout @ Max Freq).
  1.032  VISA         MEAS:VRMS? DISP,AC,CHAN[V @Chan][I]

# Calculate the gain at maximum frequency (Gain @ Max Freq) in dB.
  1.033  MATH         MEM = 20 * LOG((MEM / Vin@MaxFreq) / Gain@50MHz)

  1.034  IF           Freq == 11.8
  1.035  TSET         TDESC = [V @Range] (@ 11.8 GHz)
  1.036  ELSE
  1.037  TSET         TDESC = [V @Range]
  1.038  ENDIF

# E4412A Power Sensor cal factor uncertainty (2.4%) expressed in dB.
  1.039  ACC          0.00dB         0.206U
  1.040  MEMCX        0.00dB         3.00U

  2.001  CALL         Sub Output Off /LO
  2.002  HEAD         -2
  2.003  END
